ApplicationCredentialBuilder

Struct ApplicationCredentialBuilder 

pub struct ApplicationCredentialBuilder<'a> { /* private fields */ }
Builder for ApplicationCredential.

Implementations

Source

impl<'a> ApplicationCredentialBuilder<'a>

pub fn id<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self

The ID of the application credential used for authentication. If not provided, the application credential must be identified by its name and its owning user.

pub fn name<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self

The name of the application credential used for authentication. If provided, must be accompanied by a user object.

pub fn secret<VALUE: Into<SecretString>>(&mut self, value: VALUE) -> &mut Self

The secret for authenticating the application credential.

pub fn user<VALUE: Into<User<'a>>>(&mut self, value: VALUE) -> &mut Self

A user object, required if an application credential is identified by name and not ID.

pub fn build( &self, ) -> Result<ApplicationCredential<'a>, ApplicationCredentialBuilderError>

Builds a new ApplicationCredential.

Errors

If a required field has not been initialized.