Module get

Module get 

Validates and shows information for a token, including its expiration date and authorization scope.

Pass your own token in the X-Auth-Token request header.

Pass the token that you want to validate in the X-Subject-Token request header.

Relationship: https://docs.openstack.org/api/openstack-identity/3/rel/auth_tokens

Structs

Request
RequestBuilder
Builder for Request.

Enums

RequestBuilderError
Error type for RequestBuilder