DomainBuilder

Struct DomainBuilder 

pub struct DomainBuilder<'a> { /* private fields */ }
Builder for Domain.

Implementations

Source

impl<'a> DomainBuilder<'a>

pub fn description<VALUE: Into<Option<Cow<'a, str>>>>( &mut self, value: VALUE, ) -> &mut Self

The description of the domain.

pub fn enabled<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self

If set to true, domain is created enabled. If set to false, domain is created disabled. The default is true.

Users can only authorize against an enabled domain (and any of its projects). In addition, users can only authenticate if the domain that owns them is also enabled. Disabling a domain prevents both of these things.

pub fn explicit_domain_id<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self

The ID of the domain. A domain created this way will not use an auto-generated ID, but will use the ID passed in instead. Identifiers passed in this way must conform to the existing ID generation scheme: UUID4 without dashes.

pub fn name<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self

The name of the domain.

pub fn options<VALUE: Into<Options>>(&mut self, value: VALUE) -> &mut Self

The resource options for the domain. Available resource options are immutable.

pub fn tags<VALUE: Into<Vec<Cow<'a, str>>>>( &mut self, value: VALUE, ) -> &mut Self

pub fn build(&self) -> Result<Domain<'a>, DomainBuilderError>

Builds a new Domain.

Errors

If a required field has not been initialized.