RequestBuilder

Struct RequestBuilder 

pub struct RequestBuilder<'a> { /* private fields */ }
Builder for Request.

Implementations

Source

impl<'a> RequestBuilder<'a>

pub fn enabled(&mut self, value: bool) -> &mut Self

If set to true, then only domains that are enabled will be returned, if set to false only that are disabled will be returned. Any value other than 0, including no value, will be interpreted as true.

pub fn limit(&mut self, value: u32) -> &mut Self

pub fn marker<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self

ID of the last fetched entry

pub fn name<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self

The resource name.

pub fn build(&self) -> Result<Request<'a>, RequestBuilderError>

Builds a new Request.

Errors

If a required field has not been initialized.

Source

impl<'a> RequestBuilder<'a>

pub fn header<K, V>(&mut self, header_name: K, header_value: V) -> &mut Self

Add a single header to the Domain.

pub fn headers<I, T>(&mut self, iter: I) -> &mut Self
where I: Iterator<Item = T>, T: Into<(Option<HeaderName>, HeaderValue)>,

Add multiple headers.