EndpointBuilder

Struct EndpointBuilder 

pub struct EndpointBuilder<'a> { /* private fields */ }
Builder for Endpoint.

Implementations

Source

impl<'a> EndpointBuilder<'a>

pub fn description<VALUE: Into<Option<Cow<'a, str>>>>( &mut self, value: VALUE, ) -> &mut Self

The endpoint description. It is returned only when set on the resource.

pub fn enabled<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self

Defines whether the endpoint appears in the service catalog: - false. The endpoint does not appear in the service catalog. - true. The endpoint appears in the service catalog. Default is true.

pub fn id<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self

The endpoint ID.

pub fn interface(&mut self, value: Interface) -> &mut Self

The interface type, which describes the visibility of the endpoint. Value is: - public. Visible by end users on a publicly available network interface. - internal. Visible by end users on an unmetered internal network interface. - admin. Visible by administrative users on a secure network interface.

pub fn name<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self

(Deprecated) The endpoint name. The field will only be returned in responses when set on the resource.

This field is deprecated as it provides no value. Endpoints are better described by the combination of service, region and interface they describe or by their ID.

pub fn region<VALUE: Into<Option<Cow<'a, str>>>>( &mut self, value: VALUE, ) -> &mut Self

(Deprecated in v3.2) The geographic location of the service endpoint.

pub fn region_id<VALUE: Into<Option<Cow<'a, str>>>>( &mut self, value: VALUE, ) -> &mut Self

(Since v3.2) The ID of the region that contains the service endpoint.

pub fn service_id<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self

The UUID of the service to which the endpoint belongs.

pub fn url<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self

The endpoint URL.

pub fn build(&self) -> Result<Endpoint<'a>, EndpointBuilderError>

Builds a new Endpoint.

Errors

If a required field has not been initialized.

Source

impl<'a> EndpointBuilder<'a>

pub fn properties<I, K, V>(&mut self, iter: I) -> &mut Self
where I: Iterator<Item = (K, V)>, K: Into<Cow<'a, str>>, V: Into<Value>,