Module application_credential

Module application_credential 

/v3/users/{user_id}/application_credentials/{id} REST operations of identity

Modules

create
Creates an application credential for a user on the project to which the current token is scoped.
delete
Delete an application credential.
find
get
Show details of an application credential.
head
Get application credential resource.
list
List all application credentials for a user.