pub struct UserBuilder<'a> { /* private fields */ }Expand description
Builder for User.
Implementations
Sourceimpl<'a> UserBuilder<'a>
impl<'a> UserBuilder<'a>
Sourcepub fn default_project_id<VALUE: Into<Option<Cow<'a, str>>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn default_project_id<VALUE: Into<Option<Cow<'a, str>>>>( &mut self, value: VALUE, ) -> &mut Self
The new ID of the default project for the user.
Sourcepub fn description<VALUE: Into<Option<Cow<'a, str>>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn description<VALUE: Into<Option<Cow<'a, str>>>>( &mut self, value: VALUE, ) -> &mut Self
The description of the user resource.
Sourcepub fn domain_id<VALUE: Into<Cow<'a, str>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn domain_id<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self
The ID of the new domain for the user. The ability to change the domain of a user is now deprecated, and will be removed in subsequent release. It is already disabled by default in most Identity service implementations.
Sourcepub fn enabled<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn enabled<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Enables or disables the user. An enabled user can authenticate and
receive authorization. A disabled user cannot authenticate or receive
authorization. Additionally, all tokens that the user holds become no
longer valid. If you reenable this user, pre-existing tokens do not
become valid. To enable the user, set to true. To disable the user,
set to false. Default is true.
Sourcepub fn federated<VALUE: Into<Vec<Federated<'a>>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn federated<VALUE: Into<Vec<Federated<'a>>>>( &mut self, value: VALUE, ) -> &mut Self
List of federated objects associated with a user. Each object in the
list contains the idp_id and protocols. protocols is a list of
objects, each of which contains protocol_id and unique_id of the
protocol and user respectively. For example:
"federated": [
{
"idp_id": "efbab5a6acad4d108fec6c63d9609d83",
"protocols": [
{"protocol_id": mapped, "unique_id": "test@example.com"}
]
}
]Sourcepub fn name<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self
pub fn name<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self
The new name for the user. Must be unique within the owning domain.
Sourcepub fn options<VALUE: Into<Options<'a>>>(&mut self, value: VALUE) -> &mut Self
pub fn options<VALUE: Into<Options<'a>>>(&mut self, value: VALUE) -> &mut Self
The resource options for the user. Available resource options are
ignore_change_password_upon_first_use, ignore_password_expiry,
ignore_lockout_failure_attempts, lock_password,
multi_factor_auth_enabled, and multi_factor_auth_rules
ignore_user_inactivity.