pub struct MappingBuilder<'a> { /* private fields */ }Expand description
Builder for Mapping.
Implementations
Sourceimpl<'a> MappingBuilder<'a>
impl<'a> MappingBuilder<'a>
Sourcepub fn allowed_redirect_uris<VALUE: Into<Vec<Cow<'a, str>>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn allowed_redirect_uris<VALUE: Into<Vec<Cow<'a, str>>>>( &mut self, value: VALUE, ) -> &mut Self
List of allowed redirect urls (only for oidc type).
Sourcepub fn bound_audiences<VALUE: Into<Vec<Cow<'a, str>>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn bound_audiences<VALUE: Into<Vec<Cow<'a, str>>>>( &mut self, value: VALUE, ) -> &mut Self
List of audiences that must be present in the token.
Sourcepub fn bound_subject<VALUE: Into<Cow<'a, str>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn bound_subject<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self
Token subject value that must be set in the token.
Sourcepub fn domain_id<VALUE: Into<Cow<'a, str>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn domain_id<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self
domain_id owning the attribute mapping.
Unset domain_id means the attribute mapping is shared and can be used
by different domains. This requires domain_id_claim to be present.
Attribute mapping can be only shared when the referred identity
provider is also shared (does not set the domain_id attribute).
Sourcepub fn domain_id_claim<VALUE: Into<Cow<'a, str>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn domain_id_claim<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self
domain_id claim name.
Sourcepub fn enabled<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn enabled<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Mapping enabled property. Inactive mappings can not be used for login.
Sourcepub fn groups_claim<VALUE: Into<Cow<'a, str>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn groups_claim<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self
groups claim name.
Sourcepub fn id<VALUE: Into<Option<Cow<'a, str>>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn id<VALUE: Into<Option<Cow<'a, str>>>>( &mut self, value: VALUE, ) -> &mut Self
Attribute mapping ID for federated logins.
Sourcepub fn idp_id<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self
pub fn idp_id<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self
ID of the federated identity provider for which this attribute mapping can be used.
Sourcepub fn name<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self
pub fn name<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self
Attribute mapping name for federated logins.
Sourcepub fn oidc_scopes<VALUE: Into<Vec<Cow<'a, str>>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn oidc_scopes<VALUE: Into<Vec<Cow<'a, str>>>>( &mut self, value: VALUE, ) -> &mut Self
List of OIDC scopes.
Sourcepub fn token_project_id<VALUE: Into<Cow<'a, str>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn token_project_id<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self
Fixed project_id for the token.
Sourcepub fn token_restriction_id<VALUE: Into<Option<Cow<'a, str>>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn token_restriction_id<VALUE: Into<Option<Cow<'a, str>>>>( &mut self, value: VALUE, ) -> &mut Self
Token restrictions to be applied to the granted token.
Sourcepub fn user_id_claim<VALUE: Into<Cow<'a, str>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn user_id_claim<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self
user_id claim name.
Sourcepub fn user_name_claim<VALUE: Into<Cow<'a, str>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn user_name_claim<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self
user_name claim name.