MappingBuilder

Struct MappingBuilder 

pub struct MappingBuilder<'a> { /* private fields */ }
Builder for Mapping.

Implementations

Source

impl<'a> MappingBuilder<'a>

pub fn allowed_redirect_uris<VALUE: Into<Vec<Cow<'a, str>>>>( &mut self, value: VALUE, ) -> &mut Self

List of allowed redirect urls (only for oidc type).

pub fn bound_audiences<VALUE: Into<Vec<Cow<'a, str>>>>( &mut self, value: VALUE, ) -> &mut Self

List of audiences that must be present in the token.

pub fn bound_subject<VALUE: Into<Option<Cow<'a, str>>>>( &mut self, value: VALUE, ) -> &mut Self

Token subject value that must be set in the token.

pub fn domain_id<VALUE: Into<Option<Cow<'a, str>>>>( &mut self, value: VALUE, ) -> &mut Self

domain_id owning the attribute mapping.

Unset domain_id means the attribute mapping is shared and can be used by different domains. This requires domain_id_claim to be present. Attribute mapping can be only shared when the referred identity provider is also shared (does not set the domain_id attribute).

pub fn domain_id_claim<VALUE: Into<Option<Cow<'a, str>>>>( &mut self, value: VALUE, ) -> &mut Self

pub fn enabled<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self

Mapping enabled property. Inactive mappings can not be used for login.

pub fn groups_claim<VALUE: Into<Option<Cow<'a, str>>>>( &mut self, value: VALUE, ) -> &mut Self

groups claim name.

pub fn idp_id<VALUE: Into<Option<Cow<'a, str>>>>( &mut self, value: VALUE, ) -> &mut Self

ID of the federated identity provider for which this attribute mapping can be used.

pub fn name<VALUE: Into<Option<Cow<'a, str>>>>( &mut self, value: VALUE, ) -> &mut Self

Attribute mapping name for federated logins.

pub fn oidc_scopes<VALUE: Into<Vec<Cow<'a, str>>>>( &mut self, value: VALUE, ) -> &mut Self

List of OIDC scopes.

pub fn token_project_id<VALUE: Into<Option<Cow<'a, str>>>>( &mut self, value: VALUE, ) -> &mut Self

Fixed project_id for the token.

pub fn token_restriction_id<VALUE: Into<Option<Cow<'a, str>>>>( &mut self, value: VALUE, ) -> &mut Self

Token restrictions to be applied to the granted token.

pub fn _type(&mut self, value: Type) -> &mut Self

Attribute mapping type.

pub fn user_id_claim<VALUE: Into<Option<Cow<'a, str>>>>( &mut self, value: VALUE, ) -> &mut Self

user_id claim name.

pub fn user_name_claim<VALUE: Into<Option<Cow<'a, str>>>>( &mut self, value: VALUE, ) -> &mut Self

user_name claim name.

pub fn build(&self) -> Result<Mapping<'a>, MappingBuilderError>

Builds a new Mapping.

Errors

If a required field has not been initialized.

Source

impl<'a> MappingBuilder<'a>

pub fn bound_claims<I, K, V>(&mut self, iter: I) -> &mut Self
where I: Iterator<Item = (K, V)>, K: Into<Cow<'a, str>>, V: Into<Value>,

Additional claims that must be present in the token.