pub struct DomainBuilder<'a> { /* private fields */ }Expand description
Builder for Domain.
Implementations
Sourceimpl<'a> DomainBuilder<'a>
impl<'a> DomainBuilder<'a>
Sourcepub fn description<VALUE: Into<Option<Cow<'a, str>>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn description<VALUE: Into<Option<Cow<'a, str>>>>( &mut self, value: VALUE, ) -> &mut Self
The description of the domain.
Sourcepub fn enabled<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn enabled<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
If set to true, domain is created enabled. If set to false, domain
is created disabled. The default is true.
Users can only authorize against an enabled domain (and any of its projects). In addition, users can only authenticate if the domain that owns them is also enabled. Disabling a domain prevents both of these things.
Sourcepub fn explicit_domain_id<VALUE: Into<Cow<'a, str>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn explicit_domain_id<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self
The ID of the domain. A domain created this way will not use an auto-generated ID, but will use the ID passed in instead. Identifiers passed in this way must conform to the existing ID generation scheme: UUID4 without dashes.
Sourcepub fn name<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self
pub fn name<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self
The name of the domain.