pub struct RequestBuilder<'a> { /* private fields */ }Expand description
Builder for Request.
Implementations
Sourceimpl<'a> RequestBuilder<'a>
impl<'a> RequestBuilder<'a>
Sourcepub fn enabled(&mut self, value: bool) -> &mut Self
pub fn enabled(&mut self, value: bool) -> &mut Self
If set to true, then only domains that are enabled will be returned, if set to false only that are disabled will be returned. Any value other than 0, including no value, will be interpreted as true.
pub fn limit(&mut self, value: u32) -> &mut Self
Sourcepub fn marker<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self
pub fn marker<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self
ID of the last fetched entry