pub struct EndpointBuilder<'a> { /* private fields */ }Expand description
Builder for Endpoint.
Implementations
Sourceimpl<'a> EndpointBuilder<'a>
impl<'a> EndpointBuilder<'a>
Sourcepub fn description<VALUE: Into<Option<Cow<'a, str>>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn description<VALUE: Into<Option<Cow<'a, str>>>>( &mut self, value: VALUE, ) -> &mut Self
The endpoint description. It is returned only when set on the resource.
Sourcepub fn enabled<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn enabled<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
Defines whether the endpoint appears in the service catalog: - false.
The endpoint does not appear in the service catalog. - true. The
endpoint appears in the service catalog. Default is true.
Sourcepub fn interface(&mut self, value: Interface) -> &mut Self
pub fn interface(&mut self, value: Interface) -> &mut Self
The interface type, which describes the visibility of the endpoint.
Value is: - public. Visible by end users on a publicly available
network interface. - internal. Visible by end users on an unmetered
internal network interface. - admin. Visible by administrative users
on a secure network interface.
Sourcepub fn name<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self
pub fn name<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self
(Deprecated) The endpoint name. The field will only be returned in responses when set on the resource.
This field is deprecated as it provides no value. Endpoints are better described by the combination of service, region and interface they describe or by their ID.
Sourcepub fn region<VALUE: Into<Option<Cow<'a, str>>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn region<VALUE: Into<Option<Cow<'a, str>>>>( &mut self, value: VALUE, ) -> &mut Self
(Deprecated in v3.2) The geographic location of the service endpoint.
Sourcepub fn region_id<VALUE: Into<Option<Cow<'a, str>>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn region_id<VALUE: Into<Option<Cow<'a, str>>>>( &mut self, value: VALUE, ) -> &mut Self
(Since v3.2) The ID of the region that contains the service endpoint.
Sourcepub fn service_id<VALUE: Into<Cow<'a, str>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn service_id<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self
The UUID of the service to which the endpoint belongs.