pub struct UserBuilder<'a> { /* private fields */ }Expand description
Builder for User.
Implementations
Sourceimpl<'a> UserBuilder<'a>
impl<'a> UserBuilder<'a>
Sourcepub fn default_project_id<VALUE: Into<Option<Cow<'a, str>>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn default_project_id<VALUE: Into<Option<Cow<'a, str>>>>( &mut self, value: VALUE, ) -> &mut Self
The ID of the default project for the user. A user’s default project must not be a domain. Setting this attribute does not grant any actual authorization on the project, and is merely provided for convenience. Therefore, the referenced project does not need to exist within the user domain. (Since v3.1) If the user does not have authorization to their default project, the default project is ignored at token creation. (Since v3.1) Additionally, if your default project is not valid, a token is issued without an explicit scope of authorization.
Sourcepub fn description<VALUE: Into<Option<Cow<'a, str>>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn description<VALUE: Into<Option<Cow<'a, str>>>>( &mut self, value: VALUE, ) -> &mut Self
The description of the user resource.
Sourcepub fn domain_id<VALUE: Into<Cow<'a, str>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn domain_id<VALUE: Into<Cow<'a, str>>>( &mut self, value: VALUE, ) -> &mut Self
The ID of the domain of the user. If the domain ID is not provided in the request, the Identity service will attempt to pull the domain ID from the token used in the request. Note that this requires the use of a domain-scoped token.
Sourcepub fn enabled<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
pub fn enabled<VALUE: Into<bool>>(&mut self, value: VALUE) -> &mut Self
If the user is enabled, this value is true. If the user is disabled,
this value is false.
Sourcepub fn federated<VALUE: Into<Vec<Federated<'a>>>>(
&mut self,
value: VALUE,
) -> &mut Self
pub fn federated<VALUE: Into<Vec<Federated<'a>>>>( &mut self, value: VALUE, ) -> &mut Self
List of federated objects associated with a user. Each object in the
list contains the idp_id and protocols. protocols is a list of
objects, each of which contains protocol_id and unique_id of the
protocol and user respectively. For example:
"federated": [
{
"idp_id": "efbab5a6acad4d108fec6c63d9609d83",
"protocols": [
{"protocol_id": mapped, "unique_id": "test@example.com"}
]
}
]Sourcepub fn name<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self
pub fn name<VALUE: Into<Cow<'a, str>>>(&mut self, value: VALUE) -> &mut Self
The user name. Must be unique within the owning domain.
Sourcepub fn options<VALUE: Into<Options<'a>>>(&mut self, value: VALUE) -> &mut Self
pub fn options<VALUE: Into<Options<'a>>>(&mut self, value: VALUE) -> &mut Self
The resource options for the user. Available resource options are
ignore_change_password_upon_first_use, ignore_password_expiry,
ignore_lockout_failure_attempts, lock_password,
multi_factor_auth_enabled, and multi_factor_auth_rules
ignore_user_inactivity.